%define anolis_release 1
%global tmpfiles 1

%bcond_with xmlrpc

Name:		certmonger
Version:	0.79.20
Release:	%{anolis_release}%{?dist}
Summary:	Certificate status monitor and PKI enrollment client

License:	GPL-3.0-or-later
URL:		http://pagure.io/certmonger/
Source0:	https://pagure.io/certmonger/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	gettext-devel
BuildRequires:	gcc
BuildRequires:	openldap-devel
BuildRequires:	krb5-devel
BuildRequires:	libidn2-devel
BuildRequires:	dbus-devel, nspr-devel, nss-devel, openssl-devel
BuildRequires:	libuuid-devel
BuildRequires:	libtalloc-devel, libtevent-devel
BuildRequires:	libcurl-devel
BuildRequires:	libxml2-devel
%if %{with xmlrpc}
BuildRequires:  xmlrpc-c-devel
%endif
BuildRequires:  jansson-devel
# Required for 'make check':
#  for diff and cmp
BuildRequires:	diffutils
#  for expect
BuildRequires:	expect
#  for certutil and pk12util
BuildRequires:	nss-tools
#  for openssl
BuildRequires:	openssl
#  for dbus-launch
BuildRequires:	/usr/bin/dbus-launch
#  for dos2unix
BuildRequires:	/usr/bin/dos2unix
BuildRequires:	/usr/bin/unix2dos
#  for which
BuildRequires:	/usr/bin/which
#  for dbus tests
BuildRequires:	python3-dbus
BuildRequires:	popt-devel

# we need a running system bus
Requires:	dbus
Requires(post):	%{_bindir}/dbus-send

BuildRequires:	systemd-units
BuildRequires: make
Requires(post):	systemd-units
Requires(preun):	systemd-units, dbus, sed
Requires(postun):	systemd-units

%global systemdsysvsave %{nil}

# Certain versions of libtevent have incorrect internal ABI versions.
Conflicts: libtevent < 0.9.13

%description
Certmonger is a service which is primarily concerned with getting your
system enrolled with a certificate authority (CA) and keeping it enrolled.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

sed -i 's,^# chkconfig: - ,# chkconfig: 345 ,g' sysvinit/certmonger.in

%build
autoreconf -i -f
%configure \
	--enable-systemd \
	--enable-tmpfiles \
	--with-homedir=/run/certmonger \
%if %{with xmlrpc}
    --with-xmlrpc \
%endif
	--disable-dsa \
	--with-tmpdir=/run/certmonger --enable-pie --enable-now
%if %{with xmlrpc}
make %{?_smp_mflags} XMLRPC_LIBS="-lxmlrpc_client -lxmlrpc_util -lxmlrpc"
%else
make %{?_smp_mflags}
%endif

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/%{_localstatedir}/lib/certmonger/{cas,requests}
install -m755 -d $RPM_BUILD_ROOT/run/certmonger
%{find_lang} %{name}

%generate_compatibility_deps

%check
make check

%post
if test $1 -eq 1 ; then
	%{_bindir}/dbus-send --system --type=method_call --dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig 2>&1 || :
fi
%if %{without xmlrpc}
# remove any existing certmaster CA configuration
if test $1 -gt 1 ; then
    %{_bindir}/getcert remove-ca -c certmaster 2>&1 || :
fi
%endif

%postun
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
	/bin/systemctl try-restart certmonger.service >/dev/null 2>&1 || :
fi
exit 0

%preun
if test $1 -eq 0 ; then
	/bin/systemctl --no-reload disable certmonger.service > /dev/null 2>&1 || :
	/bin/systemctl stop certmonger.service > /dev/null 2>&1 || :
fi
exit 0

%files -f %{name}.lang
%license LICENSE
%dir %{abidir}
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/*
%{_datadir}/dbus-1/services/*
%dir %{_sysconfdir}/certmonger
%config(noreplace) %{_sysconfdir}/certmonger/certmonger.conf
%dir /run/certmonger
%{_bindir}/*
%{_sbindir}/certmonger
%{_mandir}/man*/*
%{_libexecdir}/%{name}
%{_localstatedir}/lib/certmonger
%attr(0644,root,root) %config(noreplace) %{_tmpfilesdir}/certmonger.conf
%{_unitdir}/*
%{_datadir}/dbus-1/system-services/*

%files doc
%doc README.md STATUS doc/*.txt

%changelog
* Thu Feb 27 2025 Zhao Hang <wb-zh951434@alibaba-inc.com> - 0.79.20-1
- Update to 0.79.20-1 from 0.79.18-1
- Remove patch which already exist in upstream

* Fri Apr 07 2023 Funda Wang <fundawang@yeah.net> - 0.79.18-1
- Import package for anolis 23
